# anemoi-models

[![Documentation Status](https://readthedocs.org/projects/anemoi-models/badge/?version=latest)](https://anemoi-models.readthedocs.io/en/latest/?badge=latest)

**DISCLAIMER**
This project is **BETA** and will be **Experimental** for the foreseeable future.
Interfaces and functionality are likely to change, and the project itself may be scrapped.
**DO NOT** use this software in any project/software that is operational.

Miscellanous tools for training data-driven weather forecasts.

## Documentation

The documentation can be found at https://anemoi-models.readthedocs.io/.

## Install

Install via `pip` with:

```
$ pip install anemoi-models
```

## License

```
Copyright 2024, Anemoi contributors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

In applying this licence, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation
nor does it submit to any jurisdiction.
```
